import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.Random;

public class Snake extends JFrame {
    private static int ROWS = 15;
    private static int BOX_WIDTH = 40;
    private class SnakePanel extends JPanel
        implements KeyListener, ActionListener {
        private int k = KeyEvent.VK_DOWN;
        private int x = 0;
        private int y = 0;
        private int[][] board = new int[ROWS][ROWS];
        private Random generator = new Random();
        public SnakePanel() {
            for (int i=0; i<ROWS; i++) {
                for (int j=0; j<ROWS; j++) {
                    board[i][j] = 0;
                }
            }
            board[x][y] = 4;
            placeFood();
        }
        private void placeFood() {
            int x = generator.nextInt(ROWS);
            int y = generator.nextInt(ROWS);
            for (int i=0; i<ROWS; i++) {
                for (int j=0; j<ROWS; j++) {
                    if (board[(i+x) % ROWS][(j+y) % ROWS] == 0) {
                        board[(i+x) % ROWS][(j+y) % ROWS] = -1;
                        return;
                    }
                }
            }
        }
        public void paintComponent(Graphics g) {
            super.paintComponent(g);
            for (int i=0; i<ROWS; i++) {
                for (int j=0; j<ROWS; j++) {
                    if (board[i][j] > 0) {
                        g.fillRect(i*BOX_WIDTH,j*BOX_WIDTH,
                                   BOX_WIDTH,BOX_WIDTH);
                    } else if (board[i][j] < 0) {
                        g.drawOval(i*BOX_WIDTH,j*BOX_WIDTH,
                                   BOX_WIDTH,BOX_WIDTH);
                    }
                }
            }
        }
        public void actionPerformed(ActionEvent e) {
            int old = board[x][y];
            if (k == KeyEvent.VK_DOWN && y < ROWS-1) {
                y++;
            } else if (k == KeyEvent.VK_UP && 0 < y) {
                y--;
            } else if (k == KeyEvent.VK_LEFT && 0 < x) {
                x--;
            } else if (k == KeyEvent.VK_RIGHT && x < ROWS-1) {
                x++;
            }
            board[x][y] = old+1;
            for (int i=0; i<ROWS; i++) {
                for (int j=0; j<ROWS; j++) {
                    if (board[i][j] > 0) {
                        board[i][j] = board[i][j]-1;
                    }
                }
            }
            repaint();
        }
        public void keyPressed(KeyEvent e) {
            k = e.getKeyCode();
        }
        public void keyTyped(KeyEvent e) {}
        public void keyReleased(KeyEvent e) {}
    }
    public Snake() {
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocation(50,50);
        SnakePanel panel = new SnakePanel();
        addKeyListener(panel);
        panel.setPreferredSize(new java.awt.Dimension(ROWS*BOX_WIDTH,ROWS*BOX_WIDTH));
        add(panel); pack(); setVisible(true);
        Timer t = new Timer(100,panel);
        t.start();
    }
    public static void main(String[] args) {
        Snake f = new Snake();
    }
}
